from functools import partial
from .parquet.ttypes import *


def __getattr__(name):
    # for compatability with coe that calls, e.g., parquet_thrift.RowGroup(...)
    from fastparquet.cencoding import ThriftObject
    if name[0].isupper():
        return partial(ThriftObject.from_fields, thrift_name=name)
    raise AttributeError(name)



"""parquet - read parquet files."""

from fastparquet._version import __version__
from fastparquet.writer import write, update_file_custom_metadata
from fastparquet import core, schema, converted_types, api
from fastparquet.api import ParquetFile
from fastparquet.util import ParquetException

